# 0.8.1 / 2019-07-02

  * return rows indicies of out-of-bag samples in bootcorr

# 0.8.0 / 2019-06-04

  * bootstrap samples for correlation estimation

# 0.7.0 / 2019-04-22

  * mincorr algorithm added to find a given number of low-correlated features

# 0.6.1 / 2019-03-19

  * Fix #1 "autocorrect option for mcc"

# 0.6.0 / 2018-11-28

  * Search rule to find the best and worst correlations

# 0.5.2 / 2018-11-28

  * slice_yx, output vectors as (n,) vectors instead of (n,1)

# 0.5.0 / 2018-11-28

  * slice_yx, slice a correlation and p-value matrix of a (y,X) dataset
    into a (y,x_i) vector and (x_j, x_k) matrices

# 0.4.1 / 2018-11-28

  * confusion_to_mcc, Use the confusion matrix as input as well as the four metrics

# 0.4.0 / 2018-11-27

  * Confusion matrix 
  * Matthews correlation

# 0.3.0 / 2018-11-21

  * corr_vs_pval and bracket_pval added

# 0.2.0 / 2018-11-20

  * correlogram added

# 0.1.0 / 2018-10-31

  * Initial Release
